/**
  *  \file client/widgets/buildorderdisplay.cc
  *  \brief WBuildOrderDisplay widget
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/buildorderdisplay.h"
#include "cpluslib/format.h"
#include "game/spec.h"
#include "gfx/gfxcontext.h"
#include "int/if/baseif.h"
#include "ui/uiglobal.h"
#include "ui/util.h"
#include "util/nls.h"

/** \class WBuildOrderDisplay
    \brief Display a Build Order

    This will display a build order on the ship build screen. */
WBuildOrderDisplay::WBuildOrderDisplay()
{
    o.hull = 0;
}

void
WBuildOrderDisplay::drawContent(GfxCanvas& can)
{
    GfxContext ctx;
    ctx.useCanvas(can).useColorScheme(getSkin()).useFont(*fonts[FONT_NORMAL]);

    int x = getExtent().x;
    int y = getExtent().y;
    int w = getExtent().w;
    int dy = font_heights[FONT_NORMAL];

    drawBackground(ctx, getExtent());
    
    if (o.hull) {
        ctx.setColor(UIColor::tc_Contrast);
        outTextF(ctx, x, y, w, _("Your order:"));
        y += dy;
        ctx.setColor(UIColor::tc_Static);
        outTextFormatted(ctx, x, y, w, formatBuildOrder(o));
    }
    can.update(getExtent());
}

void
WBuildOrderDisplay::getLayoutInfo(LayoutInfo& info)
{
    info.flags = 0;
    info.min_size = info.pref_size = font_sizes[FONT_NORMAL].scaledBy(20, 5);
}

void
WBuildOrderDisplay::setBuildOrder(const TBuildOrder& o)
{
    this->o = o;
    drawWidget();
}
