/**
  *  \file client/widgets/objchart.cc
  *  \brief Class WObjectSelectionChartWidget
  *
  *  \todo Supporting objects without radius would also be possible.
  *  This is currently only used for minefields, though, where that is not required.
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <algorithm>
#include "client/widgets/objchart.h"
#include "client/chart.h"
#include "game/bbox.h"
#include "game/global.h"
#include "game/obj.h"
#include "gfx/font.h"
#include "gfx/gfxcontext.h"
#include "gfx/palette.h"
#include "ui/uiglobal.h"
#include "ui/util.h"

WObjectSelectionChartWidget::WObjectSelectionChartWidget(GObjectSelection& selection)
    : WObjectSelectionObserverTile(GfxPoint(9 * font_heights[FONT_NORMAL],
                                            9 * font_heights[FONT_NORMAL]),
                                   selection)
{ }

void
WObjectSelectionChartWidget::drawData(GfxCanvas& can)
{
    // Draw container
    GfxRect ex = getExtent();
    ex.x = 0;                       // Tiles use 0-based coordinates!
    ex.y = 0;
    drawFrameDown(can, ex);
    ex.grow(-1, -1);
    drawSolidBar(can, ex, standard_colors[COLOR_BLACK]);

    // Draw map
    GCircularObject* co = dynamic_cast<GCircularObject*>(getCurrentObject());
    if (co) {
        // Zoom factor
        int radius = co->getRadius();
        int width  = ex.w / 2;
        int divi   = (width <= 0
                      ? 1
                      : std::max(1, std::min(int(GChartBBox::MAX_ZOOM), (radius + width-1) / width)));

        // Minefield present
        GChartViewport vp;
        vp.view   = ex;
        vp.center = co->getPos();
        vp.mult   = 1;
        vp.divi   = divi;
        vp.vec_id = 0;
        vp.drawing_filter = vp.NO_FILTER;
        vp.init();
        vp.draw(can,
                getChartOpts(true, vp.mult, vp.divi),
                getDisplayedTurn().getCurrentUniverse(),
                getDisplayedTurn().getChartBBox());

        // Highlight it
        GfxContext ctx;
        ctx.useCanvas(can);
        ctx.useColorScheme(GfxStandardColorScheme::instance);
        ctx.setColor(COLOR_GRAY);
        drawCircle(ctx, vp.scaleXY(co->getPos()), vp.scale(co->getRadius()));
    } else {
        // No minefield present
    }

    // Finish
    can.update(getExtent());
}
