/**
  *  \file client/widgets/pluginlist.h
  *  \brief Class WPluginList
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_PLUGINLIST_H
#define PCC_V2_CLIENT_WIDGETS_PLUGINLIST_H

#include <vector>
#include "util/pluginmgr.h"
#include "ui/listbox.h"

/** Display list of plugins.
    The plugin manager might change due to installation or uninstallation.
    This would make lifetime management a mess if we'd store Plugin pointers.
    Therefore, we just copy out the information we need. */
class WPluginList : public UIListbox {
 public:
    WPluginList(int id);

    ~WPluginList();

    void init(const PluginManager& mgr);

    void drawPart(GfxCanvas& can, int from, int to);

    string_t getCurrentPluginId() const;

 private:
    struct Item {
        string_t id;
        string_t name;
        bool loaded;
        Item(const string_t& id, const string_t& name, bool loaded)
            : id(id), name(name), loaded(loaded)
            { }
    };
    std::vector<Item> content;
};

#endif
