/**
  *  \file game/msgparse.h
  *  \brief Message Parser
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_MSGPARSE_H
#define PCC_V2_GAME_MSGPARSE_H

#include "game/msgtemplate.h"
#include "cpluslib/ptrvector.h"

class Stream;
class GMessageInformation;

class GMessageParser {
    ptr_vector<GMessageTemplate> message_templates;

 public:
    GMessageParser();
    ~GMessageParser();

    void load(Stream& s);
    void done();
    void dump();

    void parseMessage(string_t theMessage, int player, int turn, ptr_vector<GMessageInformation>& info_out);

    uint32_t getNumTemplates() const;
    const GMessageTemplate& getTemplate(uint32_t i) const;
};


inline uint32_t
GMessageParser::getNumTemplates() const
{
    return message_templates.size();
}

inline const GMessageTemplate&
GMessageParser::getTemplate(uint32_t i) const
{
    return *message_templates[i];
}

#endif
