/**
  *  \file game/shiptransfer.h
  *  \brief Ship Cargo Transfer
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_SHIPTRANSFER_H
#define PCC_V2_GAME_SHIPTRANSFER_H

#include "game/cargo.h"
#include "game/ship.h"

/** Ship Cargo Transfer. Describes the ship's main cargo hold for
    cargo transfer and transaction purposes. */
class GShipTransfer : public GCargoContainer {
    GShip& ship;
 protected:
    int32_t getCargoOnObject(GCargoType type);
    void    changeCargoOnObject(GCargoType type, int32_t amount);
    void    changeReservedCargo(GCargoType type, int32_t amount);
 public:
    GShipTransfer(GShip& ship);
    ~GShipTransfer();

    bool     canHaveCargo(GCargoType cargo_id);
    int32_t  getMaxCargo(GCargoType cargo_id);
    string_t getName() const;
    int32_t  getDisplayOffset(GCargoType type);

    GShip&   getShip();
};

/** Ship Cargo Transporter. Describes the ship/ship or ship/planet
    (resp. ship/space) transporter. For each ship and each
    transporter, only one object of this type can exist at any given
    time. */
class GShipTransporterTransfer : public GCargoContainer {
    GShip&             ship;     //!< The ship whose transporter we're using.
    TShipTransfer&     transfer; //!< The transporter we're using.
    GObject*           other;    //!< The other object (null if jettison).
    GShip::Transporter which_one;//!< Transporter identifier.
    TShipTransfer      reserve;  //!< Reservations, to handle GCargoContainer protocol.
 protected:
    int32_t getCargoOnObject(GCargoType type);
    void    changeCargoOnObject(GCargoType type, int32_t amount);
    void    changeReservedCargo(GCargoType type, int32_t amount);
 public:
    GShipTransporterTransfer(GShip& ship, GShip::Transporter which_one, GObject& other);
    GShipTransporterTransfer(GShip& ship);
    ~GShipTransporterTransfer();

    bool     canHaveCargo(GCargoType cargo_id);
    int32_t  getMaxCargo(GCargoType cargo_id);
    string_t getName() const;
    int32_t  getDisplayOffset(GCargoType type);
};


inline GShip&
GShipTransfer::getShip()
{
    return ship;
}

#endif
