/**
  *  \file gfx/gfxcontext.cc
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "gfx/gfxcontext.h"
#include "gfx/gfx.h"

/***************************** GfxColorScheme ****************************/

GfxColorScheme::~GfxColorScheme()
{ }

/*************************** GfxNullColorScheme **************************/

GfxNullColorScheme GfxNullColorScheme::instance;

uint32_t
GfxNullColorScheme::getColor(uint32_t index)
{
    return index;
}

void
GfxNullColorScheme::drawBackground(GfxContext& ctx, GfxRect area)
{
    if (!ctx.isTransparentBackground())
        drawSolidBar(ctx, area, 0);
}

/******************************* GfxContext ******************************/

GfxContext::GfxContext()
    : raw_color(0),
      line_thickness(1),
      line_pattern(SOLID_LINE),
      transparent_background(true),
      fill_pattern(SOLID_FILL),
      alpha(GFX_ALPHA_OPAQUE),
      cursor(0, 0),
      text_align(0, 0),
      font(0),
      canvas(0),
      color_scheme(&GfxNullColorScheme::instance)
{ }

GfxContext&
GfxContext::setColor(uint32_t color)
{
    this->raw_color = color_scheme->getColor(color);
    return *this;
}

GfxContext&
GfxContext::setFillPattern(const GfxFillPattern& pat)
{
    this->fill_pattern = pat;
    return *this;
}
