/**
  *  \file ui/widgets/decimalsel.h
  *  \brief UIDecimalSelector widget
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_WIDGETS_DECIMALSEL_H
#define PCC_V2_UI_WIDGETS_DECIMALSEL_H

#include "ui/widgets/numbersel.h"

/** \class UIDecimalSelector
    \brief A "move-or-type" number selector.

    This widget provides behaviour close to a normal input line (i.e.,
    digits "echo" and backspace deletes), but also accepts '+' or '-'
    resp. cursor keys like all number selectors.

    Internal consistency model: this maintains a consistent value all
    the time. Special states affect display only. For example, assume
    /low/=3, and value is 5. If the user deletes that using backspace,
    the internal stored value will still be 3 but the widget displays
    an empty line. If the user enters a '9' now, the value will be 9,
    not 39. There still is the problem that the user cannot enter a
    value such as 10, because 1 would be below our minimum. */
class UIDecimalSelector : public UINumberSelector {
    enum State {
        sTypeErase,
        sZeroed,
        sNormal
    };
    State state;
    int fixed_width;
    void wState(State s);
 public:
    enum {
        pds_RightJust = 2*st_Last,
        pds_ShowMax   = 4*st_Last
    };
    
    UIDecimalSelector(int id, long low, long high, int step);
    ~UIDecimalSelector();
    bool handleEvent(const UIEvent& e, bool second_pass);
    void onStateChange(int state, bool enabled);
    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo& li);
    void setDisplayState(bool typeerase);
    void setFixedWidth(int n);
    virtual string_t getStringValue();
};


#endif
